# The code in this file is redundant with code in notebooks/scaling_plots.ipynb
# I think this is desirable though, to allow easier hacking of analysis code in the notebook

from typing import Any, Dict, List, Optional

from matplotlib import pyplot as plt
import seaborn as sns
import pickle as pkl

import bigbench.benchmark_tasks
from bigbench.api import results

import numpy as np
import dataclasses
import os

sns.set(font_scale=1.2)
sns.set_style("whitegrid")


@dataclasses.dataclass
class PlotSettings:
    marker: Optional[str] = None
    palette: Optional[str] = None
    linestyle: Optional[str] = None
    label: Optional[str] = None


DEFAULT_PLOT_SETTINGS = PlotSettings()
PALETTES = ["crest", "flare", "rocket", "mako", "magma", "viridis"]
LINESTYLES = ["-", "--", "-.", ":", "solid", "dashed", "dashdot", "dotted"]
MARKERS = [".", "o", "x", "d", "*", "v", "+"]

with open(
    os.path.join(
        os.path.dirname(bigbench.benchmark_tasks.__file__), "task_human_eval.pkl"
    ),
    "rb",
) as f:
    eval_dicts = pkl.load(f)
    HUMAN_EVAL_DICT = eval_dicts["average"]
    MAX_HUMAN_EVAL_DICT = eval_dicts["expert"]

PLOT_SETTINGS = {
    "BIG-G T=0": PlotSettings(
        marker="d", palette="flare", linestyle="-", label="BIG-G"
    ),
    "BIG-G sparse": PlotSettings(
        marker="d", palette="flare", linestyle="dashed", label="BIG-G sparse"
    ),
    "GPT": PlotSettings(marker="o", palette="crest", linestyle="dashed", label="GPT"),
    "BIG-G T=1": PlotSettings(
        marker="*", palette="crest", linestyle="-.", label="BIG-G T=1"
    ),
}


def plot_task(
    task_data: results.TaskData,
    subtask: str,
    metric: str,
    shots: Optional[List[int]] = None,
    model_families: Optional[List[str]] = None,
    plot_settings: Optional[Dict[str, PlotSettings]] = PLOT_SETTINGS,
    plot_human: bool = True,
    normalize_mc_grade: bool = False,
    plot_random: bool = True,
):

    task_name = task_data.name
    axes = plt.gca()

    if subtask not in task_data.subtasks:
        raise ValueError(f"subtask {subtask} not found")

    if metric not in task_data.data[subtask]:
        raise ValueError(f"metric {metric} not found")

    normalize_results = (
        metric == "multiple_choice_grade"
        and normalize_mc_grade
        and task_data.preferred_metric == "multiple_choice_grade"
    )

    min_score = task_data.preferred_metric_low
    max_score = task_data.preferred_metric_high

    normalize_fn = lambda x: 100 * (x - min_score) / (max_score - min_score)

    if model_families is None:
        model_families = sorted(task_data.data[subtask][metric].keys())

    for model_family in model_families:
        if model_family not in task_data.data[subtask][metric]:
            continue

        if shots is None:
            shots = task_data.data[subtask][metric][model_family].keys()

        model_plot_settings = plot_settings.get(model_family, DEFAULT_PLOT_SETTINGS)

        palette = model_plot_settings.palette or random.choice(PALETTES)
        linestyle = model_plot_settings.linestyle or random.choice(LINESTYLES)
        marker = model_plot_settings.marker or random.choice(MARKERS)
        model_label = model_plot_settings.label or model_family

        for shot, color in zip(shots, sns.color_palette(palette, len(shots))):

            scores = task_data.scores(
                subtask=subtask, metric=metric, shots=shot, model_family=model_family
            )
            xdata = [x.params for x in scores]
            ydata = [x.score for x in scores]

            if normalize_results:
                ydata = [normalize_fn(y) for y in ydata]

            plt.semilogx(
                xdata,
                ydata,
                color=color,
                label=f"{model_label} ({shot}-shot)",
                linestyle=linestyle,
                marker=marker,
            )

    if plot_human and task_name == subtask:
        if (
            subtask in HUMAN_EVAL_DICT
            and metric in HUMAN_EVAL_DICT[subtask]
            and subtask in MAX_HUMAN_EVAL_DICT
            and metric in MAX_HUMAN_EVAL_DICT[subtask]
        ):
            human_score = HUMAN_EVAL_DICT[subtask][metric]
            max_human_score = MAX_HUMAN_EVAL_DICT[subtask][metric]

            if normalize_results:
                human_score = normalize_fn(human_score)
                max_human_score = normalize_fn(max_human_score)

            axes.axhline(
                y=max_human_score,
                color="darkblue",
                ls="--",
                linewidth=2,
                label="Best rater",
            )
            axes.axhline(
                y=human_score, color="blue", ls="--", linewidth=2, label="Average rater"
            )

    if (
        metric == "multiple_choice_grade"
        and plot_random
        and (not normalize_mc_grade)
        and task_data.preferred_metric == "multiple_choice_grade"
    ):
        axes.axhline(y=min_score, linewidth=2, color="black", ls="-.", label="Random")

    axes.legend(framealpha=1, loc="best")
    axes.grid(True, which="both")
    axes.set_title(f"{subtask}")
    axes.set_xlabel(f"FLOP-matched non-embedding parameters")
    axes.set_ylabel(metric)
