# Copyright 2021 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Helper functions for the BIG-bench SeqIO code."""

import re
from typing import Any, Iterable, Mapping, Sequence, Tuple

INVALID_TASK_NAME_RE = re.compile(r'[^\w\d\.\:_]')


def format_name_for_seqio(name: str) -> str:
  """Formats BIG-bench task names to be SeqIO compatible."""
  # SeqIO Task/Mixture names are validated by
  # seqio.dataset_providers._VALID_TASK_NAME_REGEX.
  return INVALID_TASK_NAME_RE.sub('_', name)
